@@ -9,6 +9,7 @@
 extern "C" 
 { 
 #include "../../../../C/7zCrc.h"
+#include "../../../../C/CpuArch.h"
 }
 
 // define FORMAT_7Z_RECOVERY if you want to recover multivolume archives with empty StartHeader 
@@ -96,11 +97,7 @@ void CStreamSwitch::Set(CInArchive *archive, const CObjectVector<CByteBuffer> *d
   }
 }
 
-#if defined(_M_IX86) || defined(_M_X64) || defined(_M_AMD64) || defined(__i386__) || defined(__x86_64__)
-#define SZ_LITTLE_ENDIAN_UNALIGN
-#endif
-
-#ifdef SZ_LITTLE_ENDIAN_UNALIGN
+#ifdef LITTLE_ENDIAN_UNALIGN
 static inline UInt16 GetUInt16FromMem(const Byte *p) { return *(const UInt16 *)p; }
 static inline UInt32 GetUInt32FromMem(const Byte *p) { return *(const UInt32 *)p; }
 static inline UInt64 GetUInt64FromMem(const Byte *p) { return *(const UInt64 *)p; }
@@ -220,10 +217,8 @@ static inline bool TestSignatureCandidate(const Byte *p)
 
 HRESULT CInArchive::FindAndReadSignature(IInStream *stream, const UInt64 *searchHeaderSizeLimit)
 {
-  UInt32 processedSize; 
-  RINOK(ReadStream(stream, _header, kHeaderSize, &processedSize));
-  if (processedSize != kHeaderSize)
-    return S_FALSE;
+  RINOK(ReadStream_FALSE(stream, _header, kHeaderSize));
+
   if (TestSignatureCandidate(_header))
     return S_OK;
 
@@ -240,6 +235,7 @@ HRESULT CInArchive::FindAndReadSignature(IInStream *stream, const UInt64 *search
       if (curTestPos - _arhiveBeginStreamPosition > *searchHeaderSizeLimit)
         break;
     UInt32 numReadBytes = kBufferSize - numPrevBytes;
+    UInt32 processedSize;
     RINOK(stream->Read(buffer + numPrevBytes, numReadBytes, &processedSize));
     UInt32 numBytesInBuffer = numPrevBytes + processedSize;
     if (numBytesInBuffer < kHeaderSize)
@@ -607,7 +603,9 @@ void CInArchive::ReadStreamsInfo(
   for (;;)
   {
     UInt64 type = ReadID();
-    switch(type)
+    if (type > ((UInt32)1 << 30))
+      ThrowIncorrect();
+    switch((UInt32)type)
     {
       case NID::kEnd:
         return;
@@ -627,6 +625,8 @@ void CInArchive::ReadStreamsInfo(
             unPackSizes, digestsDefined, digests);
         break;
       }
+      default:
+        ThrowIncorrect();
     }
   }
 }
@@ -664,7 +664,7 @@ void CInArchive::ReadBoolVector2(int numItems, CBoolVector &v)
 }
 
 void CInArchive::ReadTime(const CObjectVector<CByteBuffer> &dataVector,
-    CObjectVector<CFileItem> &files, UInt64 type)
+    CObjectVector<CFileItem> &files, UInt32 type)
 {
   CBoolVector boolVector;
   ReadBoolVector2(files.Size(), boolVector);
@@ -881,8 +881,10 @@ HRESULT CInArchive::ReadHeader(
     if (type == NID::kEnd)
       break;
     UInt64 size = ReadNumber();
-    database.ArchiveInfo.FileInfoPopIDs.Add(type);
-    switch(type)
+    bool isKnownType = true;
+    if (type > ((UInt32)1 << 30))
+      isKnownType = false;
+    else switch((UInt32)type)
     {
       case NID::kName:
       {
@@ -951,15 +953,16 @@ HRESULT CInArchive::ReadHeader(
       case NID::kLastWriteTime:
       case NID::kLastAccessTime:
       {
-        ReadTime(dataVector, database.Files, type);
+        ReadTime(dataVector, database.Files, (UInt32)type);
         break;
       }
       default:
-      {
-        database.ArchiveInfo.FileInfoPopIDs.DeleteBack();
-        SkeepData(size);
-      }
+        isKnownType = false;
     }
+    if (isKnownType)
+      database.ArchiveInfo.FileInfoPopIDs.Add(type);
+    else
+      SkeepData(size);
   }
 
   CNum emptyFileIndex = 0;
