@@ -74,12 +74,19 @@ static void SetFileHeader(
   item.UnPackSize = updateItem.Size;
   bool isDirectory;
 
+  item.ClearFlags();
+
   if (updateItem.NewProperties)
   {
     isDirectory = updateItem.IsDirectory;
     item.Name = updateItem.Name; 
+    item.SetUtf8(updateItem.IsUtf8);
     item.ExternalAttributes = updateItem.Attributes;
     item.Time = updateItem.Time;
+    item.NtfsMTime = updateItem.NtfsMTime;
+    item.NtfsATime = updateItem.NtfsATime;
+    item.NtfsCTime = updateItem.NtfsCTime;
+    item.NtfsTimeIsDefined = updateItem.NtfsTimeIsDefined;
   }
   else
     isDirectory = item.IsDirectory();
@@ -91,7 +98,6 @@ static void SetFileHeader(
   item.ExtractVersion.HostOS = kExtractHostOS;
 
   item.InternalAttributes = 0; // test it
-  item.ClearFlags();
   item.SetEncrypted(!isDirectory && options.PasswordIsDefined);
   if (isDirectory)
   {
@@ -141,7 +147,7 @@ struct CThreadInfo
 
   NWindows::CThread Thread;
   NWindows::NSynchronization::CAutoResetEvent CompressEvent;
-  NWindows::NSynchronization::CAutoResetEvent CompressionCompletedEvent;
+  NWindows::NSynchronization::CAutoResetEventWFMO CompressionCompletedEvent;
   bool ExitThread;
 
   CMtCompressProgress *ProgressSpec;
@@ -165,10 +171,10 @@ struct CThreadInfo
       Coder(options)
   {}
   
-  HRESULT CreateEvents()
+  HRESULT CreateEvents(CSynchro *sync)
   {
     RINOK(CompressEvent.CreateIfNotCreated());
-    return CompressionCompletedEvent.CreateIfNotCreated();
+    return CompressionCompletedEvent.CreateIfNotCreated(sync);
   }
   HRes CreateThread() { return Thread.Create(CoderThread, this); }
 
@@ -346,7 +352,13 @@ static HRESULT UpdateItemOldData(COutArchive &archive,
     // item.ExternalAttributes = updateItem.Attributes;
     // Test it
     item.Name = updateItem.Name; 
+    item.SetUtf8(updateItem.IsUtf8);
     item.Time = updateItem.Time;
+    item.NtfsMTime = updateItem.NtfsMTime;
+    item.NtfsATime = updateItem.NtfsATime;
+    item.NtfsCTime = updateItem.NtfsCTime;
+    item.NtfsTimeIsDefined = updateItem.NtfsTimeIsDefined;
+
     item.CentralExtra.RemoveUnknownSubBlocks();
     item.LocalExtra.RemoveUnknownSubBlocks();
     
@@ -566,6 +578,13 @@ static HRESULT Update2(
 
   #ifdef COMPRESS_MT
 
+  // Warning : before memManager, threads and compressingCompletedEvents
+  // in order to have a "good" order for the destructor
+  NWindows::NSynchronization::CSynchro synchroForCompressingCompletedEvents;
+  synchroForCompressingCompletedEvents.Create();
+  NWindows::NSynchronization::CSynchro synchroForOutStreamSpec;
+  synchroForOutStreamSpec.Create();
+
   CObjectVector<CItem> items;
 
   CMtProgressMixer *mtProgressMixerSpec = new CMtProgressMixer;
@@ -583,7 +602,7 @@ static HRESULT Update2(
   CRecordVector<int> threadIndices;  // list threads in order of updateItems
 
   {
-    RINOK(memManager.AllocateSpaceAlways((size_t)numThreads * (kMemPerThread / kBlockSize)));
+    RINOK(memManager.AllocateSpaceAlways(&synchroForOutStreamSpec,(size_t)numThreads * (kMemPerThread / kBlockSize)));
     for(i = 0; i < updateItems.Size(); i++)
       refs.Refs.Add(CMemBlocks2());
 
@@ -598,9 +617,9 @@ static HRESULT Update2(
       threadInfo._codecsInfo = codecsInfo;
       threadInfo._externalCodecs = externalCodecs;
       #endif
-      RINOK(threadInfo.CreateEvents());
+      RINOK(threadInfo.CreateEvents(&synchroForCompressingCompletedEvents));
       threadInfo.OutStreamSpec = new COutMemStream(&memManager);
-      RINOK(threadInfo.OutStreamSpec->CreateEvents());
+      RINOK(threadInfo.OutStreamSpec->CreateEvents(&synchroForOutStreamSpec));
       threadInfo.OutStream = threadInfo.OutStreamSpec;
       threadInfo.IsFree = true;
       threadInfo.ProgressSpec = new CMtCompressProgress();
